| rspdlite-package | R Documentation |
rspdlite relies on spdlite, a lightweight header-only C++20 library for logging. This package offers a simple and consistent interface from both R and C++.
spdlite is the ‘little brother’ of spdlog (which we have available via R packages RcppSpdlog and spdl). spdlite is on purpose smaller and simpler. It has (by choice) fewer options and configuration settings keeping the core small and simple.
By using a global inline instance, each shared library (i.e. typically
each package using logging) is guaranteed to have exactly one instance. So
setting changes such as the logging level affect both the R and C++ side. If
however another R package were to be compiled with the spdlite header,
its instance would be separate as it resides in a different shared library.
Similarly, an ad-hoc compilation via e.g. Rcpp::sourceCpp() will lead
to a distinct instance for the same reason.
Maintainer: Dirk Eddelbuettel edd@debian.org (0000-0001-6419-907X)
Authors:
Gabi Melman (Author of spdlog)
Victor Zverovic (Author of fmt)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.